<?php
/**
 * Custom CSS addition
 *
 * @package Decree Pro
 */

if ( ! function_exists( 'decree_custom_css' ) ) :
	/**
	 * Enqueue Custon CSS
	 *
	 * @uses  set_transient, wp_head, wp_enqueue_style
	 *
	 * @action wp_enqueue_scripts
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_custom_css() {
		// decree_flush_transients();
		$output = '';

		$options  = decree_get_theme_options();
		$defaults = decree_get_default_theme_options();
		$fonts    = decree_avaliable_fonts();

		$output = get_transient( 'decree_custom_css' );

		if ( ! $output ) {
			$text_color = get_header_textcolor();

			if ( 'blank' === $text_color ) {
				$output	.= '.site-title a, .site-description { position: absolute !important; clip: rect(1px 1px 1px 1px); clip: rect(1px, 1px, 1px, 1px); }' . PHP_EOL;
			} elseif ( $defaults['header_textcolor'] !== $text_color ) {
				$output	.= '.site-title a, .site-description { color: #' . $text_color . '; }' . PHP_EOL;
			}

			$output .= decree_get_custom_colors( $options );

			$output .= decree_get_custom_fonts( $options, $defaults );

			$output .= decree_get_section_backgrounds( $options, $defaults );

			/*
			 * Custom css for social icons. needs change: @change
			 */
			if ( $defaults['social_icon_size'] !== $options['social_icon_size'] && '' !== $options['social_icon_size'] ) {
				$size 	= $options['social_icon_size'];

				$output .= '.widget_decree_social_icons .fa { font-size:' . esc_attr( $size ) . 'px; }' . PHP_EOL;
			}

			// Custom CSS Option.
			if ( ! empty( $options['custom_css'] ) ) {
				$output	.= $options['custom_css'] . '' . PHP_EOL;
			}

			if ( '' !== $output ) {
				$output = '<!-- ' . get_bloginfo( 'name' ) . ' inline CSS Styles -->' . PHP_EOL . '<style type="text/css" media="screen" rel="ct-custom-css">' . PHP_EOL . $output;

				$output .= '</style>' . PHP_EOL;

			}

			set_transient( 'decree_custom_css', htmlspecialchars_decode( $output ), 86940 );
		} // End if().

		echo $output;
	}
endif; // decree_custom_css().
add_action( 'wp_head', 'decree_custom_css', 101 );


/**
 * Get parsed css list of custom colors from theme customizer
 *
 * @param  array $options list of theme options.
 * @return string          parsed list of custom css.
 */
function decree_get_custom_colors( $options ) {
	$output = '';

	$defaults = decree_get_default_theme_options();

	$color_headings = apply_filters( 'decree_color_options', 'color_headings' );
	$color_headings = array_keys( $color_headings );

	$unparsed_colors = array();
	$unparsed_property = array();

	/**
	 *	First Sort each color selector and its property and value
	 *	$unparsed_colors list of CSS selectors
	 *	$unparsed_property list of properties and values in form property:value
	 */
	foreach ( $color_headings as $color_heading ) {
		$color_options	= apply_filters( 'decree_color_options', $color_heading );

		foreach ( $color_options as $key => $value ) {
			if ( $defaults[ $key ] !== $options[ $key ] ) {
				$unparsed_colors[] = $value['css_selector'];

				if ( 'contact_info_bg_color' === $key ) {
					$rgba = decree_hex2rgb( $options[ $key ] );

					$unparsed_property[] = $value['css_property'] . ': rgba( ' . absint( $rgba['red'] ) . ', ' . absint( $rgba['green'] ) . ', ' . absint( $rgba['blue'] ) . ', 0.4 )';
				} else {
					$unparsed_property[] = $value['css_property'] . ': ' . esc_attr( $options[ $key ] );
				}
			}// End if().
		} // End foreach().
	} // End foreach().

	$parsed_colors = array();

	/**
	 *	Parse colors by combining elements wigh same selector.
	 */
	$counter = 0;
	foreach ( $unparsed_colors as $unparsed_colors ) {
		if ( array_key_exists( $unparsed_colors, $parsed_colors ) ) {
			$parsed_colors[ $unparsed_colors ] = $parsed_colors[ $unparsed_colors ] . '; ' . $unparsed_property[ $counter++ ];
		} else {
			$parsed_colors[ $unparsed_colors ] = $unparsed_property[ $counter++ ];
		}
	}

	/**
	 * Finally combine all CSS combination to one
	 */
	foreach ( $parsed_colors as $key => $value ) {
		$output .= $key . ' { ' . $value . '; }' . PHP_EOL;
	}
	return $output;
}


/**
 * Returns custom font css from theme customizer
 *
 * @param  array $options theme options.
 * @param  array $defaults default options.
 * @return string parsed list of custom css
 */
function decree_get_custom_fonts( $options, $defaults ) {
	$output = '';
	$fonts  = decree_avaliable_fonts();

	// Typography (Font Family) Options.
	if ( $defaults['body_font'] !== $options['body_font'] ) {
		$output	.= 'body, button, input, select, textarea, #supplementary .menu, .sidebar-primary .menu { font-family: ' . $fonts[ $options['body_font'] ]['label'] . '; }' . PHP_EOL;
	}
	if ( $defaults['title_font'] !== $options['title_font'] ) {
		$output	.= '.site-title { font-family: ' . $fonts[ $options['title_font'] ]['label'] . '; }' . PHP_EOL;
	}
	if ( $defaults['tagline_font'] !== $options['tagline_font'] ) {
		$output	.= '.site-description { font-family: ' . $fonts[ $options['tagline_font'] ]['label'] . '; }' . PHP_EOL;
	}
	if ( $defaults['menu_font'] !== $options['menu_font'] ) {
		$output	.= '.menu { font-family: ' . $fonts[ $options['menu_font'] ]['label'] . '; }' . PHP_EOL;
	}
	if ( $defaults['content_title_font'] !== $options['content_title_font'] ) {
		$output	.= '.page-title, #main .entry-container .entry-title, #featured-content .entry-title { font-family: ' . $fonts[ $options['content_title_font'] ]['label'] . '; }' . PHP_EOL;
	}
	if ( $defaults['content_font'] !== $options['content_font'] ) {
		$output	.= '#main .entry-container, #featured-content { font-family: ' . $fonts[ $options['content_font'] ]['label'] . '; }' . PHP_EOL;
	}
	if ( $defaults['headings_font'] !== $options['headings_font'] ) {
		$output	.= 'h1, h2, h3, h4, h5, h6 { font-family: ' . $fonts[ $options['headings_font'] ]['label'] . '; }' . PHP_EOL;
	}

	return $output;
}


if ( ! function_exists( 'decree_get_section_backgrounds' ) ) :
	/**
	 * Section Backgrounds
	 *
	 * @param  array $options theme options.
	 * @param  array $defaults default options.
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_get_section_backgrounds( $options, $defaults ) {
		$output = '';

		if ( $defaults['featured_content_bg_image'] !== $options['featured_content_bg_image'] ) {
			if ( $options['featured_content_bg_image'] ) {
				$output	.= '#featured-content { background-image: url( "' . esc_url( $options['featured_content_bg_image'] ) . '" ); }' . PHP_EOL;
			} else {
				$output	.= '#featured-content { background-image: none; }' . PHP_EOL;
			}
		}

		if ( $defaults['promotion_headline_bg_image'] !== $options['promotion_headline_bg_image'] ) {
			if ( '' !== $options['promotion_headline_bg_image'] ) {
				$output	.= '#promotion-headline-section { background-image: url( "' . esc_url( $options['promotion_headline_bg_image'] ) . '" ); }' . PHP_EOL;
			} else {
				$output	.= '#promotion-headline-section { background-image: none; }' . PHP_EOL;
			}
		}

		if ( $defaults['contact_page_bg_image'] !== $options['contact_page_bg_image'] ) {
			if ( $options['contact_page_bg_image'] ) {
				$output	.= '#contact-page-section { background-image: url( "' . esc_url( $options['contact_page_bg_image'] ) . '" ); }' . PHP_EOL;
			} else {
				$output	.= '#contact-page-section { background-image: none; }' . PHP_EOL;
			}
		}

		if ( $defaults['logo_slider_bg_image'] !== $options['logo_slider_bg_image'] ) {
			if ( $options['logo_slider_bg_image'] ) {
				$output	.= '#logo-section { background-image: url( "' . esc_url( $options['logo_slider_bg_image'] ) . '" ); }' . PHP_EOL;
			} else {
				$output	.= '#logo-section { background-image: none; }' . PHP_EOL;
			}
		}

		return $output;
	}
endif; // decree_get_section_backgrounds.


/**
 * Converts a HEX value to RGB.
 *
 * @since Decree Pro 1.0
 *
 * @param string $color The original color, in 3- or 6-digit hexadecimal form.
 * @return array Array containing RGB (red, green, and blue) values for the given
 *               HEX code, empty array otherwise.
 */
function decree_hex2rgb( $color ) {
	$color = trim( $color, '#' );

	if ( strlen( $color ) === 3 ) {
		$r = hexdec( substr( $color, 0, 1 ) . substr( $color, 0, 1 ) );
		$g = hexdec( substr( $color, 1, 1 ) . substr( $color, 1, 1 ) );
		$b = hexdec( substr( $color, 2, 1 ) . substr( $color, 2, 1 ) );
	} elseif ( strlen( $color ) === 6 ) {
		$r = hexdec( substr( $color, 0, 2 ) );
		$g = hexdec( substr( $color, 2, 2 ) );
		$b = hexdec( substr( $color, 4, 2 ) );
	} else {
		return array();
	}

	return array(
		'red' => $r,
		'green' => $g,
		'blue' => $b,
	);
}
