<?php
/**
 * Active callbacks for Theme/Customzer Options
 *
 * @package Decree Pro
 */


if( ! function_exists( 'decree_is_portfolio_active' ) ) :
	/**
	* Return true if header highlight content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_portfolio_active( $control ) {
		$enable = $control->manager->get_setting( 'decree_theme_options[portfolio_option]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( decree_check_section( $enable ) );
	}
endif;


if( ! function_exists( 'decree_is_demo_portfolio_inactive' ) ) :
	/**
	* Return true if demo header highlight content is inactive
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_demo_portfolio_inactive( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[portfolio_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is not demo content
		return ( decree_is_portfolio_active( $control ) && !( 'demo' === $type ) );
	}
endif;


if( ! function_exists( 'decree_is_portfolio_post_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_portfolio_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[portfolio_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is post content
		return ( decree_is_portfolio_active( $control ) && 'post' === $type );
	}
endif;


if( ! function_exists( 'decree_is_jetpack_portfolio_active' ) ) :
	/**
	* Return true if CPT is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_jetpack_portfolio_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[portfolio_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is post content
		return ( decree_is_portfolio_active( $control ) && 'jetpack-portfolio' === $type );
	}
endif;


if( ! function_exists( 'decree_is_portfolio_page_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_portfolio_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[portfolio_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is page content
		return ( decree_is_portfolio_active( $control ) && 'page' === $type );
	}
endif;


if( ! function_exists( 'decree_is_portfolio_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_portfolio_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[portfolio_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is category content
		return ( decree_is_portfolio_active( $control ) && 'category' === $type );
	}
endif;


if( ! function_exists( 'decree_is_portfolio_image_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_portfolio_image_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[portfolio_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is image content
		return ( decree_is_portfolio_active( $control ) && 'image' === $type );
	}
endif;


if( ! function_exists( 'decree_is_portfolio_embed_content_active' ) ) :
	/**
	* Return true if embed content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_portfolio_embed_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[portfolio_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is embed content
		return ( decree_is_portfolio_active( $control ) && 'embed' === $type );
	}
endif;


if( ! function_exists( 'decree_is_post_category_portfolio_inactive' ) ) :
	/**
	* Return true if post or category content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_post_category_portfolio_inactive( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[portfolio_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is post or category content
		return ( decree_is_portfolio_active( $control ) && ( 'post' === $type || 'category' === $type ) );
	}
endif;


if( ! function_exists( 'decree_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_slider_active( $control ) {
		$enable = $control->manager->get_setting( 'decree_theme_options[featured_slider_option]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( decree_check_section( $enable ) );
	}
endif;


if( ! function_exists( 'decree_is_demo_slider_inactive' ) ) :
	/**
	* Return true if demo slider is inactive
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_demo_slider_inactive( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( decree_is_slider_active( $control ) && !( 'demo' === $type ) );
	}
endif;


if( ! function_exists( 'decree_is_post_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_post_slider_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( decree_is_slider_active( $control ) && ( 'post' === $type ) );
	}
endif;


if( ! function_exists( 'decree_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_page_slider_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( decree_is_slider_active( $control ) && ( 'page' === $type ) );
	}
endif;


if( ! function_exists( 'decree_is_category_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_category_slider_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( decree_is_slider_active( $control ) && ( 'category' === $type ) );
	}
endif;


if( ! function_exists( 'decree_is_image_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_image_slider_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( decree_is_slider_active( $control ) && ( 'image' === $type ) );
	}
endif;

if( ! function_exists( 'decree_is_featured_content_active' ) ) :
	/**
	* Return true if featured content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_featured_content_active( $control ) {
		$enable = $control->manager->get_setting( 'decree_theme_options[featured_content_option]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( decree_check_section( $enable ) );
	}
endif;


if( ! function_exists( 'decree_is_demo_featured_content_inactive' ) ) :
	/**
	* Return true if demo featured content is inactive
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_demo_featured_content_inactive( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( decree_is_featured_content_active( $control ) && !( 'demo' === $type ) );
	}
endif;


if( ! function_exists( 'decree_is_featured_post_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_featured_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( decree_is_featured_content_active( $control ) && ( 'post' === $type ) );
	}
endif;


if( ! function_exists( 'decree_is_featured_page_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_featured_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( decree_is_featured_content_active( $control ) && ( 'page' === $type ) );
	}
endif;


if( ! function_exists( 'decree_is_featured_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_featured_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( decree_is_featured_content_active( $control ) && ( 'category' === $type ) );
	}
endif;


if( ! function_exists( 'decree_is_featured_page_post_category_image_content_active' ) ) :
	/**
	* Return true if page/post/category/image content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_featured_page_post_category_image_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( decree_is_featured_content_active( $control ) && ( 'category' === $type || 'page' === $type ) || 'post' === $type || 'image' === $type );
	}
endif;


if( ! function_exists( 'decree_is_featured_image_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_featured_image_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( decree_is_featured_content_active( $control ) && ( 'image' === $type ) );
	}
endif;


if ( ! function_exists( 'decree_is_testimonial_active' ) ) :
	/**
	* Return true if testimonial is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_testimonial_active( $control ) {
		$enable = $control->manager->get_setting( 'decree_theme_options[testimonial_option]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( decree_check_section( $enable ) );
	}
endif;


if ( ! function_exists( 'decree_is_demo_testimonial_inactive' ) ) :
	/**
	* Return true if demo testimonial is inactive
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_demo_testimonial_inactive( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[testimonial_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_testimonial_active( $control ) && !( 'demo' === $type ) );
	}
endif;


if ( ! function_exists( 'decree_is_post_testimonial_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_post_testimonial_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[testimonial_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_testimonial_active( $control ) && 'post' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_jetpack_testimonial_active' ) ) :
	/**
	* Return true if jetpack testimonial is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_jetpack_testimonial_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[testimonial_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_testimonial_active( $control ) && 'jetpack-testimonial' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_page_testimonial_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_page_testimonial_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[testimonial_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_testimonial_active( $control ) && 'page' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_category_testimonial_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_category_testimonial_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[testimonial_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_testimonial_active( $control ) && 'category' === $type );
	}
endif;

if ( ! function_exists( 'decree_is_post_page_category_cpt_testimonial_active' ) ) :
	/**
	* Return true if demo and image page is not active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_post_page_category_cpt_testimonial_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[testimonial_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_testimonial_active( $control ) && ( 'demo' !== $type && 'image' !== $type  ) );
	}
endif;


if ( ! function_exists( 'decree_is_image_testimonial_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_image_testimonial_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[testimonial_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_testimonial_active( $control ) && 'image' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_hero_content_active' ) ) :
	/**
	* Return true if hero content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_hero_content_active( $control ) {
		$enable = $control->manager->get_setting( 'decree_theme_options[hero_content_option]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( decree_check_section( $enable ) );
	}
endif;


if ( ! function_exists( 'decree_is_demo_hero_content_inactive' ) ) :
	/**
	* Return true if demo hero content is inactive
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_demo_hero_content_inactive( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[hero_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_hero_content_active( $control ) && !( 'demo' === $type ) );
	}
endif;


if ( ! function_exists( 'decree_is_hero_post_content_active' ) ) :
	/**
	* Return true if post content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_hero_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[hero_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_hero_content_active( $control ) && 'post' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_hero_page_content_active' ) ) :
	/**
	* Return true if hero page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_hero_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[hero_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_hero_content_active( $control ) && 'page' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_hero_category_content_active' ) ) :
	/**
	* Return true if hero category content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_hero_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[hero_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_hero_content_active( $control ) && 'category' === $type );
	}
endif;

if ( ! function_exists( 'decree_is_hero_post_page_category_content_active' ) ) :
	/**
	* Return true if hero post/page/category content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_hero_post_page_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[hero_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_hero_content_active( $control ) && ( 'page' === $type || 'post' === $type || 'category' === $type ) );
	}
endif;


if ( ! function_exists( 'decree_is_hero_custom_content_active' ) ) :
	/**
	* Return true if hero custom content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_hero_custom_content_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[hero_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_hero_content_active( $control ) && ( 'image' === $type ) );
	}
endif;


if ( ! function_exists( 'decree_is_logo_slider_active' ) ) :
	/**
	* Return true if logo_slider is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_logo_slider_active( $control ) {
		$enable = $control->manager->get_setting( 'decree_theme_options[logo_slider_option]' )->value();

		//return true only if previwed page on customizer matches the type of logo_slider option selected
		return ( decree_check_section( $enable ) );
	}
endif;


if ( ! function_exists( 'decree_is_demo_logo_slider_inactive' ) ) :
	/**
	* Return true if demo logo_slider is inactive
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_demo_logo_slider_inactive( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[logo_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_logo_slider_active( $control ) && !( 'demo' === $type ) );
	}
endif;


if ( ! function_exists( 'decree_is_logo_post_slider_active' ) ) :
	/**
	* Return true if post content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_logo_post_slider_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[logo_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_logo_slider_active( $control ) && 'post' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_logo_page_slider_active' ) ) :
	/**
	* Return true if hero page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_logo_page_slider_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[logo_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_logo_slider_active( $control ) && 'page' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_logo_category_slider_active' ) ) :
	/**
	* Return true if hero category content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_logo_category_slider_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[logo_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_logo_slider_active( $control ) && 'category' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_logo_image_slider_active' ) ) :
	/**
	* Return true if image logo slider is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_logo_image_slider_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[logo_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_logo_slider_active( $control ) && 'image' === $type );
	}
endif;

if ( ! function_exists( 'decree_is_promo_head_active' ) ) :
	/**
	* Return true if promotion_headline is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_promo_head_active( $control ) {
		$enable = $control->manager->get_setting( 'decree_theme_options[promo_head_option]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( decree_check_section( $enable ) );
	}
endif;


if ( ! function_exists( 'decree_is_demo_promo_head_inactive' ) ) :
	/**
	* Return true if demo header highlight content is inactive
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_demo_promo_head_inactive( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[promo_head_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_promo_head_active( $control ) && !( 'demo' === $type ) );
	}
endif;


if ( ! function_exists( 'decree_is_post_promo_head_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_post_promo_head_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[promo_head_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_promo_head_active( $control ) && 'post' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_page_promo_head_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_page_promo_head_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[promo_head_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_promo_head_active( $control ) && 'page' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_category_promo_head_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_category_promo_head_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[promo_head_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_promo_head_active( $control ) && 'category' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_custom_promo_head_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_custom_promo_head_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[promo_head_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_promo_head_active( $control ) && 'custom' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_page_post_category_promo_head_active' ) ) :
	/**
	* Return true if page or post or category content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_page_post_category_promo_head_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[promo_head_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_promo_head_active( $control ) && ( 'post' === $type || 'page' === $type || 'category' === $type ) );
	}
endif;


if ( ! function_exists( 'decree_is_team_active' ) ) :
	/**
	* Return true if our team is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_team_active( $control ) {
		$enable = $control->manager->get_setting( 'decree_theme_options[team_option]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( decree_check_section( $enable ) );
	}
endif;


if ( ! function_exists( 'decree_is_demo_team_inactive' ) ) :
	/**
	* Return true if demo our team is inactive
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_demo_team_inactive( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[team_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_team_active( $control ) && !( 'demo' === $type ) );
	}
endif;


if ( ! function_exists( 'decree_is_post_team_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_post_team_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[team_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_team_active( $control ) && 'post' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_page_team_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_page_team_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[team_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_team_active( $control ) && 'page' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_category_team_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_category_team_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[team_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_team_active( $control ) && 'category' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_image_team_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_image_team_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[team_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_team_active( $control ) && 'image' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_contact_form_active' ) ) :
	/**
	* Return true if our team is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_contact_form_active( $control ) {
		$enable = $control->manager->get_setting( 'decree_theme_options[contact_form_option]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( decree_check_section( $enable ) );
	}
endif;


if ( ! function_exists( 'decree_is_page_contact_form_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_page_contact_form_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[contact_form_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_contact_form_active( $control ) && 'page' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_custom_contact_form_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_custom_contact_form_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[contact_form_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( decree_is_contact_form_active( $control ) && 'custom' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_contact_info_active' ) ) :
	/**
	* Return true if contact info is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_contact_info_active( $control ) {
		$enable = $control->manager->get_setting( 'decree_theme_options[contact_info_option]' )->value();

		return ( decree_check_section( $enable ) );
	}
endif;


if ( ! function_exists( 'decree_is_contact_info_image_active' ) ) :
	/**
	* Return true if image contact info bg is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_contact_info_image_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[contact_info_bg]' )->value();

		return ( decree_is_contact_info_active( $control ) && 'image' === $type );
	}
endif;


if ( ! function_exists( 'decree_is_contact_info_code_active' ) ) :
	/**
	* Return true if embed code contact info bg is active
	*
	* @since Decree Pro 1.0
	*/
	function decree_is_contact_info_code_active( $control ) {
		$type = $control->manager->get_setting( 'decree_theme_options[contact_info_bg]' )->value();

		return ( decree_is_contact_info_active( $control ) && 'embed-code' === $type );
	}
endif;
