<?php
/**
 * The template for displaying Portfolio
 *
 * @package Decree Pro
 */

if ( ! function_exists( 'decree_portfolio_display' ) ) :
	/**
	 * Add Featured content.
	 *
	 * @uses action hook decree_before_content.
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_portfolio_display() {
		// decree_flush_transients();
		$output = '';

		$options        = decree_get_theme_options();
		$enable_content = $options['portfolio_option'];

		if ( decree_check_section( $enable_content ) ) {
			if ( ! $output = get_transient( 'decree_portfolio' ) ) {
				$type        = $options['portfolio_type'];
				$number      = $options['portfolio_number'];
				$headline    = $options['portfolio_headline'];
				$subheadline = $options['portfolio_subheadline'];
				$classes[]   = $type;
				$classes[]   = $options['portfolio_layout'];

				$output ='
					<div id="portfolios-content" class="sections ' . esc_attr( implode( ' ', $classes ) ) . '">
						<div class="wrapper">';

						if ( 'demo' === $type ) {
							$output .= '
							<div class="portfolio-heading-wrap">
								<h2 id="portfolio-heading" class="entry-title section-title">Portfolio</h2>

								<p>This is Portfolio Section.';

							if ( current_user_can( 'edit_theme_options' ) ) {
								$output .= ' You can edit this from Appearance - Customize - Theme Options - Portfolio. Details information of Portfolio can be found in our theme instructions page.';
							}

							$output .= '</p>
							</div><!-- .portfolio-heading-wrap -->';
						} elseif ( ! empty( $headline ) || ! empty( $subheadline ) ) {
							$output .= '
							<div class="portfolio-heading-wrap">';
								if ( ! empty( $headline ) ) {
									$output .= '
									<h2 id="portfolio-heading" class="entry-title section-title">'. $headline . '</h2>';
								}
								if ( ! empty( $subheadline ) ) {
									$output .= '
									<p>' . wp_kses_post( $subheadline ) . '</p>';
								}
							$output .= '
							</div><!-- .portfolio-heading-wrap -->';
						}

				$output .= '
							<div class="portfolio-wrap">';
								// Select content
								if ( 'demo' === $type ) {
									$output .= decree_demo_portfolio( $options );
								}
								else if ( 'post' === $type || 'page' === $type || 'category' === $type || 'jetpack-portfolio' === $type ) {
									$output .= decree_portfolio_post_page_category_content( $options );
								}
								elseif ( 'image' === $type ) {
									$output .= decree_portfolio_image_content( $options );
								}
								elseif ( 'embed' === $type ) {
									$output .= decree_portfolio_embed_content( $options );
								}

				$output .= '
							</div><!-- .portfolio-wrap -->
						</div><!-- .wrapper -->
					</div><!-- #portfolio -->';
			}

			set_transient( 'decree_portfolio', $output, 86940 );
		}

		echo $output;
	}
endif;
add_action( 'decree_before_content', 'decree_portfolio_display', 50 );


if ( ! function_exists( 'decree_demo_content' ) ) :
	/**
	 * This function to display header highlight posts content
	 *
	 * @get the data value from customizer options
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_demo_portfolio( $options ) {
		$output = '
			<article id="portfolio-post-1" class="post hentry post-demo">
				<figure class="portfolio-image">
					<a rel="bookmark" href="#">
						<img alt="Consultation" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/portfolio1-480x480.jpg" />
					</a>
				</figure>
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a href="#">Consultation</a>
						</h2>
					</header>
					<footer class="entry-footer">
						<p class="entry-meta">
							<span class="cat-links">
								<span class="screen-reader-text">Tag</span>
								<a rel="category tag" href="#">Personal</a>
							</span>
						</p><!-- .entry-meta -->
					</footer>
				</div><!-- .entry-container -->
			</article>

			<article id="portfolio-post-2" class="post hentry post-demo">
				<figure class="portfolio-image">
					<a rel="bookmark" href="#">
						<img alt="Arrest Warrant" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/portfolio2-480x480.jpg" />
					</a>
				</figure>
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a href="#">Arrest Warrant</a>
						</h2>
					</header>
					<footer class="entry-footer">
						<p class="entry-meta">
							<span class="cat-links">
								<span class="screen-reader-text">Tag</span>
								<a rel="category tag" href="#">Police</a>
							</span>
						</p><!-- .entry-meta -->
					</footer>
				</div><!-- .entry-container -->
			</article>';

		if ( 'three-columns' === $options['portfolio_layout'] || 'four-columns' === $options['portfolio_layout'] ) {
			$output .= '
			<article id="portfolio-post-3" class="post hentry post-demo">
				<figure class="portfolio-image">
					<a rel="bookmark" href="#">
						<img alt="Strategies" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/portfolio3-480x480.jpg" />
					</a>
				</figure>
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a href="#">Strategies</a>
						</h2>
					</header>
					<footer class="entry-footer">
						<p class="entry-meta">
							<span class="cat-links">
								<span class="screen-reader-text">Tag</span>
								<a rel="category tag" href="#">Case</a>
							</span>
						</p><!-- .entry-meta -->
					</footer>
				</div><!-- .entry-container -->
			</article>';
		}

		if ( 'four-columns' === $options['portfolio_layout'] ) {
			$output .= '
			<article id="portfolio-post-4" class="post hentry post-demo">
				<figure class="portfolio-image">
					<a href="#">
						<img alt="Reporting" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/portfolio4-480x480.jpg" />
					</a>
				</figure>
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a href="#">Reporting</a>
						</h2>
					</header>
					<footer class="entry-footer">
						<p class="entry-meta">
							<span class="cat-links">
								<span class="screen-reader-text">Tag</span>
								<a rel="category tag" href="#">Case</a>
							</span>
						</p><!-- .entry-meta -->
					</footer>
				</div><!-- .entry-container -->
			</article>';
		}

		return $output;
	}
endif; // decree_demo_content


if ( ! function_exists( 'decree_portfolio_post_page_category_content' ) ) :
	/**
	 * This function to display header highlight posts/pages/category content
	 *
	 * @param $options: decree_theme_options from customizer
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_portfolio_post_page_category_content( $options ) {
		global $post;
		$quantity     = $options['portfolio_number'];
		$no_of_post   = 0; // for number of posts.
		$post_list    = array();// list of valid post/page ids.
		$type         = $options['portfolio_type'];
		$show_content = $options['portfolio_show'];
		$output       = '';

		$args = array(
			'orderby'             => 'post__in',
			'ignore_sticky_posts' => 1, // Ignore sticky posts.
		);

		// Get valid number of posts.
		if ( 'post' === $type || 'page' === $type || 'jetpack-portfolio' === $type ) {
			$args['post_type'] = $type;

			for ( $i = 1; $i <= $quantity; $i++ ) {
				$post_id = '';

				if ( 'post' === $type ) {
					$post_id = isset( $options[ 'portfolio_post_' . $i ] ) ? $options[ 'portfolio_post_' . $i ] : false;
				} elseif ( 'page' === $type ) {
					$post_id = isset( $options[ 'portfolio_page_' . $i ] ) ? $options[ 'portfolio_page_' . $i ] : false;
				} elseif ( 'jetpack-portfolio' === $type ) {
					$post_id = isset( $options[ 'portfolio_cpt_' . $i ] ) ? $options[ 'portfolio_cpt_' . $i ] : false;
				}

				if ( $post_id && '' !== $post_id ) {
					// Polylang Support.
					if ( class_exists( 'Polylang' ) ) {
						$post_id = pll_get_post( $post_id, pll_current_language() );
					}

					$post_list = array_merge( $post_list, array( $post_id ) );
					$no_of_post++;
				}
			}

			$args['post__in'] = $post_list;
		} elseif ( 'category' === $type ) {
			$no_of_post = $quantity;

			if ( ! empty( $options['portfolio_select_category'] ) ) {
				$args['category__in'] = $options['portfolio_select_category'];
			}
		}

		if ( 0 === $no_of_post ) {
			return;
		}

		$args['posts_per_page'] = $no_of_post;

		$loop = new WP_Query( $args );

		while ( $loop->have_posts() ) {
			$loop->the_post();

			$title_attribute = the_title_attribute( 'echo=0' );

			$excerpt = get_the_excerpt();

			if ( 0 === $loop->current_post ) {
				//Set article id to large-featured-image, if it is the first image
				$article_id = 'large-featured-image';
			}
			else {
				$article_id = 'portfolio-post-' . $loop->current_post;
			}

			$output .= '
			<article id="' . esc_attr( $article_id ) . '" class="post hentry post">';
			if ( has_post_thumbnail() ) {
				//Pull post thunbnail if it is present
				$thumbnail = get_the_post_thumbnail(
					get_the_ID(),
					'post-thumbnail',
					array(
						'title' => $title_attribute,
						'alt' => $title_attribute
					)
				);
			}
			else {
				$first_image = decree_get_first_image(
					get_the_ID(),
					'post-thumbnail',
					array(
						'title' => $title_attribute,
						'alt' => $title_attribute
						)
					);

				if ( $first_image ) {
					$thumbnail = $first_image;
				}
				else {
					$thumbnail = '<img class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/no-featured-image-1920x800.jpg" >';
				}
			}

			$output .= '
				<figure class="portfolio-homepage-image">
					<a href="' . esc_url( get_permalink() ) . '">
					'. $thumbnail . '
					</a>
				</figure>';

			$output .= '
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . the_title( '','', false ) . '</a>
						</h2>
					</header>';

					if ( 'excerpt' === $show_content ) {
						$output .= '<div class="entry-summary"><p>' . $excerpt . '</p></div><!-- .entry-summary -->';
					}
					elseif ( 'full-content' === $show_content ) {
						$content = apply_filters( 'the_content', get_the_content() );
						$content = str_replace( ']]>', ']]&gt;', $content );
						$output .= '<div class="entry-content">' . $content . '</div><!-- .entry-content -->';
					}

					$footer_class = '';

					if ( $options['portfolio_hide_category'] &&  $options['portfolio_hide_tags'] && $options['portfolio_hide_date'] && $options['portfolio_hide_author'] ) {
						$footer_class = 'screen-reader-text';
					}

					$output .= '
					<footer class="entry-footer ' . $footer_class . '">
						' . decree_get_highlight_meta(
								$options['portfolio_hide_category'],
								$options['portfolio_hide_tags'],
								$options['portfolio_hide_date'],
								$options['portfolio_hide_author']
							) . '
					</footer><!-- .entry-footer -->';

				$output .= '
				</div><!-- .entry-container -->
			</article><!-- .portfolio-post-' . esc_attr( $loop->current_post ) . ' -->';
		}
		wp_reset_postdata();

		return $output;
	}
endif; // decree_portfolio_post_page_category_content


if ( ! function_exists( 'decree_portfolio_image_content' ) ) :
	/**
	 * This function to display header highlight image content
	 *
	 * @get the data value from theme options
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_portfolio_image_content( $options ) {
		$quantity 		= $options['portfolio_number'];

		$show_content	= isset( $options['portfolio_show'] ) ? $options['portfolio_show'] : 'excerpt';

		$output = '';

		for ( $i = 1; $i <= $quantity; $i++ ) {
			if ( ! empty( $options[ 'portfolio_target_' . $i ] ) ) {
				$target = '_blank';
			} else {
				$target = '_self';
			}

			//Checking Link
			if ( ! empty( $options[ 'portfolio_link_' . $i ] ) ) {
				//support qTranslate plugin
				if ( function_exists( 'qtrans_convertURL' ) ) {
					$link = qtrans_convertURL(  $options[ 'portfolio_link_' . $i ] );
				}
				else {
					$link =  $options[ 'portfolio_link_' . $i ];
				}
			}
			else {
				$link = '#';
			}

			//Checking Title
			if ( ! empty( $options[ 'portfolio_title_'. $i ] ) ) {
				$title =$options[ 'portfolio_title_'. $i ];
			}
			else {
				$title = '';
			}

			//Checking Content
			if ( ! empty( $options[ 'portfolio_content_'. $i ] ) ) {
				$content =$options[ 'portfolio_content_'. $i ];
			}
			else {
				$content = '';
			}

			$button_text   = '';
			$button_link   = '';
			$button_target = '_self';

			//Checking Button Link
			if ( ! empty( $options[ 'portfolio_button_link_' . $i ] ) ) {
				//support qTranslate plugin
				if ( function_exists( 'qtrans_convertURL' ) ) {
					$button_link = qtrans_convertURL( $options[ 'portfolio_button_link_' . $i ] );
				}
				else {
					$button_link =  $options[ 'portfolio_button_link_' . $i ];
				}
			}

			//Checking Button Text
			if ( ! empty( $options[ 'portfolio_button_text_' . $i ] ) ) {
				$button_text =  $options[ 'portfolio_button_text_' . $i ];
			}

			//Checking Button Target
			if ( isset( $options[ 'portfolio_button_target_' . $i ] ) && $options[ 'portfolio_button_target_' . $i ] ) {
				$button_target = '_blank';
			}


			if ( 1 === $i ) {
				$article_id = 'large-featured-image';
			}
			else {
				$article_id = 'portfolio-post-' . ( int )  ( $i - 1 );
			}

			$output .= '
			<article id="' . $article_id . '" class="post hentry image">';

				if ( ! empty( $options[ 'portfolio_image_' . $i ] ) ) {
					$output .= '
					<figure class="portfolio-homepage-image">
						<a title="' . esc_attr( $title ) . '" href="' . esc_url( $link ) . '" target="' . $target . '">
							<img src="'. $options[ 'portfolio_image_' . $i ] . '" class="wp-post-image" alt="' . esc_attr( $title ) . '" title="' . esc_attr( $title ) . '">
						</a>
					</figure>';
				}

				if ( '' !== $title  || $content!='' ) {
					$output .= '
					<div class="entry-container">';
						if ( '' !== $title  ) {
							$output .= '
							<header class="entry-header">
								<h2 class="entry-title">
									<a href="' . esc_url( $link ) . '" rel="bookmark" target="' . $target . '">' . $title . '</a>
								</h2>
							</header>';
						}
						if ( 'hide-content' !== $show_content || '' !== $button_link  ) {
							$output .= '<div class="entry-content">';

								if ( '' !== $content )  {
									$output .= '<p>' . $content . '</p>';
								}
								if ( '' !== $button_link ) {
									$output .= '
									<a href="'. esc_url( $button_link ).'" class="button white-button" target="'. $button_target . '">'. $button_text . '</a>';
								}
							$output .= '</div>';
						}
					$output .= '
					</div><!-- .entry-container -->';

				}
			$output .= '
			</article><!-- .portfolio-post-'.$i.' -->';

		}
		return $output;
	}
endif; //decree_portfolio_image_content


if ( ! function_exists( 'decree_portfolio_embed_content' ) ) :
	/**
	 * This function to display header highlight embed content
	 *
	 * @get the data value from theme options
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_portfolio_embed_content( $options ) {
		$quantity = $options['portfolio_number'];
		$output   = '';

		for ( $i = 1; $i <= $quantity; $i++ ) {
			if ( 1 === $i ) {
				$article_id = 'large-featured-embed';
			}
			else {
				$article_id = 'portfolio-embed-' . ( int )  ( $i );
			}

			$output .= '
			<article id="' . $article_id . '" class="post hentry embed">';

				if ( ! empty( $options['portfolio_embed_' . $i ] ) ) {
					$output .= '
					<div class="entry-container">
						' . do_shortcode( $options[ 'portfolio_embed_' . $i ] ) . '
					</div><!-- .entry-container -->';
				}
			$output .= '
			</article><!-- .portfolio-embed-'.$i.' -->';

		}
		return $output;
	}
endif; //decree_portfolio_embed_content
