<?php
/**
 * The template for displaying the Promotion Headline
 *
 * @package Decree Pro
 */


if ( ! function_exists( 'decree_promo_head_display' ) ) :
	/**
	* Add Promotion Headline.
	*
	* @uses action hook decree_before_content
	*
	* @since Decree Pro 1.0
	*/
	function decree_promo_head_display() {
		//decree_flush_transients();
		$output = '';

		$options        = decree_get_theme_options();
		$enable_content = $options['promo_head_option'];
		$content_select = $options['promo_head_type'];

		if ( decree_check_section( $enable_content ) ) {
			if ( ! $output = get_transient( 'decree_promotion_headline' ) ) {
				echo '<!-- refreshing cache -->';

				$classes[] = $content_select ;

				$output ='
					<div id="promotion-headline-section" class="sections ' . implode( ' ', $classes ) . '">
						<div class="wrapper">';
							// Select content
							if ( 'demo' === $content_select ) {
								$output .= decree_demo_promotion_headline();
							}
							elseif ( 'post' === $content_select || 'page' === $content_select || 'category' === $content_select ) {
								$output .= decree_post_page_category_promotion_headline( $options );
							}
							elseif ( 'custom' === $content_select ) {
								$output .= decree_custom_promotion_headline( $options );
							}

				$output .= '
						</div><!-- .wrapper -->
					</div><!-- #promotion-section -->';

			}

			set_transient( 'decree_promotion_headline', $output, 86940 );
		}
		echo $output;
	}
endif;
add_action( 'decree_before_content', 'decree_promo_head_display', 60 );


if ( ! function_exists( 'decree_demo_promotion_headline' ) ) :
	/**
	 * This function to display hero posts content
	 *
	 * @get the data value from customizer options
	 *
	 * @since Decree Pro 1.0
	 *
	 */
	function decree_demo_promotion_headline() {
		return '
		<h2 class="entry-title section-title">'
			. esc_html__( 'Decree Pro WordPress Theme', 'decree-pro' ) .
		'</h2>

		<p>' . esc_html__( 'This is promotion headline', 'decree-pro' ) . '<span class="promotion-buttons more-button"><span class="readmore button-one"><a class="button-minimal" href="#" target="_blank">' . esc_html__( 'Buy Now', 'decree-pro' ) . '</a></span><span class="readmore button-two"><a class="button-minimal" href="#" target="_blank">' . esc_html__( 'View More', 'decree-pro' ) . '</a></span></span></p>';
	}
endif; // decree_demo_promotion_headline


if ( ! function_exists( 'decree_post_page_category_promotion_headline' ) ) :
	/**
	 * This function to display hero posts content
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_post_page_category_promotion_headline( $options ) {
		global $post;

		$type      = $options['promo_head_type'];
		$more_text = $options['excerpt_more_text'];
		$output    = '';

		$args = array(
			'posts_per_page'      => 1,
			'ignore_sticky_posts' => 1,
		);

		if ( 'post' === $type ) {
			// Polylang Support.
			if ( class_exists( 'Polylang' ) ) {
				$options['promo_head_post'] = pll_get_post( $options['promo_head_post'], pll_current_language() );
			}

			$args['p'] = absint( $options['promo_head_post'] );
		}
		elseif ( 'page' === $type ) {
			// Polylang Support.
			if ( class_exists( 'Polylang' ) ) {
				$options['promo_head_page'] = pll_get_post( $options['promo_head_page'], pll_current_language() );
			}

			$args['post_type'] = 'page';
			$args['p']         = absint( $options['promo_head_page'] );
		}
		elseif ( 'category' === $type ) {
			$args['cat'] = absint( $options['promo_head_category'] );
		}

		$loop = new WP_Query( $args );
		while ( $loop->have_posts() ) {
			$loop->the_post();

			$content_show = $options['promo_head_show'];
			$content      = '';

			if ( 'excerpt' === $content_show ) {
				$content = get_the_excerpt();
			} elseif ( 'full-content' === $content_show ) {
				$content = apply_filters( 'the_content', get_the_content() );

				$content = str_replace( ']]>', ']]&gt;', $content );

			} else {
				$content = '<span class="promotion-buttons more-button"><span class="readmore button-one"><a class="button-minimal" href="' . esc_url( get_permalink() ) . '">' . esc_html( $more_text ) . '</a></span></span>';
			}

			if ( '' !== $content ) {
				$content = '<p>' . $content . '</p>';
			}

			$output .= the_title( '<h2 class="entry-title section-title ' . esc_attr( $post->ID ) . '">','</h2>', false ) . $content;
		} //endwhile

		wp_reset_postdata();

		return $output;
	}
endif; // decree_post_page_category_promotion_headline


if ( ! function_exists( 'decree_custom_promotion_headline' ) ) :
	/**
	 * This function to display hero posts content
	 *
	 * @get the data value from theme options
	 * @displays on the index
	 *
	 * @useage Featured Image, Title and Excerpt of Post
	 *
	 * @uses set_transient
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_custom_promotion_headline( $options ) {
		$output   = '';

		$title           = $options['promo_head_title'];
		$content         = $options['promo_head_content'];
		$button_text_1   = $options['promo_head_button'];
		$button_link_1   = $options['promo_head_url'];
		$button_target_1 = $options['promo_head_target_1'];
		$button_text_2   = $options['promo_head_button_2'];
		$button_link_2   = $options['promo_head_url_2'];
		$button_target_2 = $options['promo_head_target_2'];
		$button_one 	= '';
		$button_two 	= '';

		//Checking Button 1 Elements
		if ( $button_text_1 ) {
			if ( $button_link_1 ) {
				//support qTranslate plugin
				if ( function_exists( 'qtrans_convertURL' ) ) {
					$button_link_1 = qtrans_convertURL( $button_link_1 );
				}
			}
			else {
				$button_link_1 = '#';
			}

			if ( $button_target_1 ) {
				$button_target_1 = '_blank';
			}
			else{
				$button_target_1 = '_self';
			}

			$button_one = '<span class="readmore button-one"><a class="button-minimal" href="' . esc_url( $button_link_1 ) . '" target="' . $button_target_1 . '">' . esc_html( $button_text_1 ) . '</a></span>';
		}

		//Checking Button 2 Elements
		if ( $button_text_2 ) {
			if ( $button_link_2 ) {
				//support qTranslate plugin
				if ( function_exists( 'qtrans_convertURL' ) ) {
					$button_link_2 = qtrans_convertURL( $button_link_2 );
				}
			}
			else {
				$button_link_2 = '#';
			}

			if ( $button_target_2 ) {
				$button_target_2 = '_blank';
			}
			else{
				$button_target_2 = '_self';
			}

			$button_two = '<span class="readmore button-two"><a class="button-minimal" href="' . esc_url( $button_link_2 ) . '" target="' . $button_target_2 . '">' . esc_html( $button_text_2 ) . '</a></span>';
		}

		if ( $title ) {
			$title = '<h2 class="entry-title section-title">' . $title . '</h2>';
		}

		if ( $content ) {
			$content = '<p>' . $content;

			if ( '' !== $button_one  || '' !== $button_two  ) {
				$content .= '<span class="promotion-buttons more-button">' . $button_one . $button_two . '</span>';
			}

			$content .= '</p>';
		}

		$output .= $title . $content;

		return $output;
	}
endif; //decree_custom_content
