<?php
/**
 * The template for displaying Social Icons
 *
 * @package Decree Pro
 */


if ( ! function_exists( 'decree_get_social_icons' ) ) :
/**
 * Generate social icons.
 *
 * @since Decree Pro 1.0
 */
function decree_get_social_icons(){
	if( ( !$output = get_transient( 'decree_social_icons' ) ) ) {
		$output  = '';
		$options = decree_get_theme_options(); // Get options

		//Pre defined Social Icons Link Start
		$pre_def_icons = decree_get_social_icons_list();
		foreach ( $pre_def_icons as $key => $item ) {
			if( isset( $options[ $key ] ) && '' !== $options[ $key ] ) {
				$value = $options[ $key ];
				if ( 'email_link' === $key  ) {
					$output .= '<a class="fa fa-'. sanitize_key( $item['fa_class'] ) . '" target="_blank" title="'. esc_attr__( 'Email', 'decree-pro') . '" href="mailto:'. esc_attr( antispambot( sanitize_email( $value ) ) ) . '"><span class="screen-reader-text">'. esc_html__( 'Email', 'decree-pro') . '</span> </a>';
				}
				else if ( 'skype_link' === $key  ) {
					$output .= '<a class="fa fa-'. sanitize_key( $item['fa_class'] ) . '" target="_blank" title="'. esc_attr( $item['label'] ) . '" href="'. esc_attr( $value ) . '"><span class="screen-reader-text">'. esc_attr( $item['label'] ). '</span> </a>';
				}
				else if ( 'phone_link' === $key || 'handset_link' === $key ) {
					$output .= '<a class="fa fa-'. sanitize_key( $item['fa_class'] ) . '" target="_blank" title="'. esc_attr( $item['label'] ) . '" href="tel:' . esc_attr( preg_replace( '/\s+/', '', $value ) ) . '"><span class="screen-reader-text">'. esc_attr( $item['label'] ) . '</span> </a>';
				}
				else {
					$output .= '<a class="fa fa-'. sanitize_key( $item['fa_class'] ) . '" target="_blank" title="'. esc_attr( $item['label'] ) . '" href="'. esc_url( $value ) . '"><span class="screen-reader-text">'. esc_attr( $item['label'] ) . '</span> </a>';
				}
			}
		}
		//Pre defined Social Icons Link End

		//Custom Social Icons Link Start
		for( $i = 1; $i <= $options['custom_social_icons'] ; $i++ ) {
			$has_hover   = '';
			$image_hover = '';

			if ( ! empty( $options['custom_social_icon_image_'. $i] ) ) {
				$image = $options['custom_social_icon_image_'. $i];

				if ( ! empty( $options['custom_social_icon_image_hover_'. $i] ) ) {
					$image_hover = $options['custom_social_icon_image_hover_'. $i];
					$has_hover = " has-hover";
				}

				//Checking Link
				if ( ! empty( $options['custom_social_icon_link_'. $i] ) ) {
					$link = $options['custom_social_icon_link_'. $i];
				} else {
					$link = '#';
				}

				//Checking Title
				if ( ! empty( $options['custom_social_icon_title_'. $i]) ) {
					$title = $options['custom_social_icon_title_'. $i];
				} else {
					$title = '';
				}

				//Custom Social Icons
				$output .= '<a id="custom-icon-' . $i . '" class="custom-icon' . $has_hover . '" target="_blank" title="' . esc_attr( $title ) . '" href="' . esc_url( $link ) . '">
					<img  alt="' . esc_attr( $title ) . '" class ="icon-static" src="' . esc_url( $image ) . '" />';

					if (isset ( $image_hover ) && '' !== $image_hover ) {
					$output .= '<img  alt="' . esc_attr( $title ) . '" class ="icon-hover" src="' . esc_url( $image_hover ) . '" />';
				}
				$output .= '</a>';
			}
		}
		//Custom Social Icons Link End
		set_transient( 'decree_social_icons', $output, 86940 );
	}
	return $output;
} // decree_get_social_icons
endif;
