<?php
/**
 * Adding support for WooCommerce Plugin
 *
 * @package Decree Pro
 */

if ( ! class_exists( 'WooCommerce' ) ) {
	// Bail early if WooCommerce Plugin is not installed.
	return;
}

if ( ! function_exists( 'decree_woocommerce_setup' ) ) :
	/**
	 * Sets up support for various WooCommerce features.
	 */
	function decree_woocommerce_setup() {
		add_theme_support( 'woocommerce' );

		$options = decree_get_theme_options();

		if ( ! $options['disable_product_gallery_zoom'] ) {
			add_theme_support( 'wc-product-gallery-zoom' );
		}

		if ( ! $options['disable_product_gallery_lightbox'] ) {
			add_theme_support( 'wc-product-gallery-lightbox' );
		}

		if ( ! $options['disable_product_gallery_slider'] ) {
			add_theme_support( 'wc-product-gallery-slider' );
		}
	}
endif; // decree_woocommerce_setup.
add_action( 'after_setup_theme', 'decree_woocommerce_setup' );


remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );


if ( ! function_exists( 'decree_woocommerce_start' ) ) :
	/**
	 * WooCommerce wrap start
	 */
	function decree_woocommerce_start() {
		echo '<div class="woocommerce-wrap">';
	}
endif; // decree_woocommerce_start.
add_action( 'woocommerce_before_main_content', 'decree_woocommerce_start', 15 );


if ( ! function_exists( 'decree_woocommerce_end' ) ) :
	/**
	 * WooCommerce wrap end
	 */
	function decree_woocommerce_end() {
		echo '</div><!-- .woocommerce-wrap -->';
	}
endif; // decree_woocommerce_end.
add_action( 'woocommerce_after_main_content', 'decree_woocommerce_end', 15 );

/**
 * Add WooCommerce Options
 *
 * @param  oblect $wp_customize wp_customize object.
 */
function decree_woocommerce_options( $wp_customize ) {
	$defaults = decree_get_default_theme_options();

	// WooCommerce Options.
	$wp_customize->add_section( 'decree_woocommerce_options', array(
		'title'       => esc_html__( 'WooCommerce Options', 'decree-pro' ),
		'priority'    => 218,
		'panel'       => 'decree_theme_options',
		'description' => esc_html__( 'Since these options are added via theme support, you will need to save and refresh the customizer to view the full effect.', 'decree-pro' ),
	) );

	$wp_customize->add_setting( 'decree_theme_options[disable_product_gallery_zoom]', array(
		'default'           => $defaults['disable_product_gallery_zoom'],
		'sanitize_callback' => 'decree_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'decree_theme_options[disable_product_gallery_zoom]', array(
		'label'     => esc_html__( 'Check to disable Product Gallery Zoom', 'decree-pro' ),
		'section'   => 'decree_woocommerce_options',
		'type'      => 'checkbox',
	) );

	$wp_customize->add_setting( 'decree_theme_options[disable_product_gallery_lightbox]', array(
		'default'           => $defaults['disable_product_gallery_lightbox'],
		'sanitize_callback' => 'decree_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'decree_theme_options[disable_product_gallery_lightbox]', array(
		'label'     => esc_html__( 'Check to disable Product Gallery Lightbox', 'decree-pro' ),
		'section'   => 'decree_woocommerce_options',
		'type'      => 'checkbox',
	) );

	$wp_customize->add_setting( 'decree_theme_options[disable_product_gallery_slider]', array(
		'default'           => $defaults['disable_product_gallery_slider'],
		'sanitize_callback' => 'decree_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'decree_theme_options[disable_product_gallery_slider]', array(
		'label'     => esc_html__( 'Check to disable Product Gallery Slider', 'decree-pro' ),
		'section'   => 'decree_woocommerce_options',
		'type'      => 'checkbox',
	) );
}
add_action( 'customize_register', 'decree_woocommerce_options' );
